import { Component, EventEmitter, OnInit, Output, ViewChild } from '@angular/core';

import { FormControl, FormGroup, FormsModule, ReactiveFormsModule, Validators } from '@angular/forms';

import { MatButtonModule } from '@angular/material/button';
import { MatNativeDateModule } from '@angular/material/core';
import { MatDatepickerModule } from '@angular/material/datepicker';
import { MatFormFieldModule } from '@angular/material/form-field';
import { MatInputModule } from '@angular/material/input';
import { MatMenuModule } from '@angular/material/menu';
import { User } from '../../models/user.model';
import { NgIf } from '@angular/common';
import { UserService } from '../../services/user-service';
import { Router } from '@angular/router';

@Component({
  selector: 'app-login',
  standalone: true,
  imports: [
    MatFormFieldModule, 
    MatInputModule,
    MatButtonModule,
    MatMenuModule,
    MatDatepickerModule,
    MatNativeDateModule,
    FormsModule,
    ReactiveFormsModule,
    NgIf
  ],
  templateUrl: './login.component.html',
  styleUrl: './login.component.css'
})

export class LoginComponent implements OnInit {
  @Output() addConnectEvent = new EventEmitter<User>();
  
  public isButtonVisible = false;
  private UserService : UserService; 

  user: User = {id:1, login: '', password: '', streak: null, streaks: [], points: null}
  loginForm: FormGroup = new FormGroup({
    login: new FormControl(this.user.login, Validators.required),
    password: new FormControl(this.user.password, Validators.required),
  });

  public constructor(us: UserService,private router: Router) {
    this.UserService = us
  }

  ngOnInit() {
    sessionStorage.clear();  
  }

  connect() {  
    if (this.loginForm.invalid) {
      console.log("ERREUR INVALIDE");
      return;
    }

    if(this.loginForm.value.login != this.loginForm.value.password){
      console.log("ERREUR DIFFERENT");
      return;
    }
    console.log(this.loginForm.value.login)

    this.user = this.loginForm.value;
    localStorage.setItem('UserConnecte',String(this.user.login));
    
    //this.UserService.addUserToLocal(this.user);
    this.addConnectEvent.emit(this.user)
    this.loginForm.reset();
    this.isButtonVisible = false;
    this.router.navigate(['/accueil']);
  }

  onInputChange() {
    if(this.loginForm.value.login != "" && this.loginForm.value.password != ""){
      this.isButtonVisible = true;
    } else{
      this.isButtonVisible = false;
    }
  }
}
