import { Component } from '@angular/core';
import { RouterModule } from '@angular/router';
import { NgFor,NgIf } from '@angular/common';
import { ActivatedRoute } from '@angular/router';

import { SudokuService } from '../../services/sudoku-service';

@Component({
  selector: 'app-sudoku',
  standalone: true,
  imports: [RouterModule, NgFor, NgIf],
  templateUrl: './sudoku.component.html',
  styleUrl: './sudoku.component.css'
})
export class SudokuComponent {
  grille: number[][] = [];
  nbIndice: number = 0;
  haveWin: boolean = false;

  constructor(protected sudokuService: SudokuService, private activatedRoute: ActivatedRoute) {
  }

  ngOnInit() {
    const difficulty = this.activatedRoute.snapshot.params["difficulty"];
    this.Request(difficulty);
  }
  public publish() {
    this.resetError();
    this.haveWin = this.sudokuService.publishGame(this.getGrid(),"pas test",this.nbIndice)
    if (this.haveWin) return;
    this.corriger();
  }

  public corriger() {
    this.resetError();
    if (this.sudokuService.isCorrect(this.getGrid())) {
      this.publish();
      return;
    }
    this.nbIndice += 1;
    let error: number[][] = this.sudokuService.validationGrille(this.getGrid());
    for (let y=0; y<error.length; y++) {
      for (let x=0; x<error[y].length; x++) {
        if (error[y][x] == -1) {
          this.marqueError(x,y);
        }
      }
    }
  }

  private getGrid():number[][] {
    let grid: number[][] = [];
    for (let y=0; y<9; y++) {
      grid.push([]);
      for (let x=0; x<9; x++) {
        grid[y].push(Number((document.getElementById("xy"+y.toString()+x.toString()) as HTMLInputElement).value) | 0);
      }
    }
    return grid;
  }

  private marqueError(x:number,y:number) {
    let error = document.getElementById("xy"+y.toString()+x.toString());
    if (error == null) return;
    error.classList.add("faux");
  }

  private resetError() {
    let errors = document.getElementsByClassName("faux");
    for (let i=0; i<errors.length; i++) {
      errors[i].classList.remove("faux");
    }
  }

  private Request(difficulty: string) {
    switch (difficulty) {
      case 'easy':
        this.grille = this.sudokuService.getEasy();
        break;
      case 'medium':
        this.grille = this.sudokuService.getMedium();
        break;
      case 'hard':
        this.grille = this.sudokuService.getHard();
        break;
      default:
        this.grille = this.sudokuService.getEasy();
        break;
    }
    if (this.grille.length == 0) {
      setTimeout(()=> {this.Request(difficulty);console.log("a")},100);
    }// lancer un await ici si possible
  }
}