import { Component } from '@angular/core';
import { RouterModule } from '@angular/router';
import { NgFor } from '@angular/common';

import { User } from '../../models/user.model';
import { UserService } from '../../services/user-service';
import { UserMenuComponent } from '../user-menu/user-menu.component';

@Component({
  selector: 'app-user-list',
  standalone: true,
  imports: [RouterModule,NgFor,UserMenuComponent],
  templateUrl: './user-list.component.html',
  styleUrl: './user-list.component.css'
})
export class UserListComponent {
  users: User[] = [];
  nbPage: number = 0;
  sortBy: string = "nbPts";
  sortSens: number = 1;


  constructor(protected userService: UserService) {
  }

  ngOnInit() {
    this.nbPage = 1;
    this.users = this.userService.getAll();
    this.loadPage(0);
    console.log(this.users);
  }

  public changeWatchedvar(newVar:string) {
    if (this.sortBy == newVar) this.sortSens -= 2*this.sortSens;
    this.sortBy = newVar;
    this.nbPage = 1;
    this.loadPage(0);
  }

  public loadPage(nb: number) {
    if (this.nbPage + nb > this.userService.getNbPage() || this.nbPage + nb <= 0) {return;}
    this.nbPage += nb;
    switch(this.sortBy) {
      case 'nbPts':
        this.users = this.userService.getUserNbPts(this.nbPage,this.sortSens);
        break
      case 'streak':
        this.users = this.userService.getUserNbStreak(this.nbPage,this.sortSens);
        break;
      default:
        this.users = this.userService.getUserNbStreak(this.nbPage,this.sortSens);
        break;
    }
  }
}
