import { HttpClient, HttpErrorResponse } from '@angular/common/http';
import { Injectable } from "@angular/core";

interface apiResponseInterface {
    data: number[][],
    easy: number[][],
    medium: number[][],
    hard: number[][]
}

@Injectable()
export class SudokuService {
    private correction: number[][];
    private easy: number[][];
    private medium: number[][];
    private hard: number[][];
    private readonly sudokuApiUrl = 'https://664ba07f35bbda10987d9f99.mockapi.io/api/sudoku/1';
    private readonly saveGameApiUrl = 'https://664ba07f35bbda10987d9f99.mockapi.io/api/game';

    public constructor(private http: HttpClient){
        this.correction = [];
        this.easy = [];
        this.medium = [];
        this.hard = [];

        this.http.get<apiResponseInterface>(this.sudokuApiUrl).subscribe(apiResponse => {
            this.correction = this.transformFormat(apiResponse["data"]);
            this.easy = this.transformFormat(apiResponse["easy"]);
            this.medium = this.transformFormat(apiResponse["medium"]);
            this.hard = this.transformFormat(apiResponse["hard"]);
        });
    }

    public getCorrection(): number[][]{
        return this.correction;
    }

    public getEasy(): number[][]{
        return this.easy;
    }

    public getMedium(): number[][]{
        return this.medium;
    }

    public getHard(): number[][]{
        return this.hard;
    }

    public validationGrille(userGrille: number[][]): number[][] {
        // valide la grille et envoit la position des erreurs
        let validation: number[][] = [];
        for (let y:number = 0; y<userGrille.length; y++) {
            validation.push([]);
            for (let x:number = 0; x<userGrille[y].length; x++) {
                if (userGrille[y][x] == 0) {
                    validation[y].push(0);
                } else if (userGrille[y][x] == this.correction[y][x]) {
                    validation[y].push(1);
                } else {
                    validation[y].push(-1);
                }
            }
        }
        return validation;
    }

    public isCorrect(userGrille: number[][]): boolean {
        // verrifie si la grille est complette et juste
        for (let x:number = 0; x<userGrille.length; x++) {
            for (let y:number = 0; y<userGrille[x].length; y++) {
                if (userGrille[x][y] == 0 || userGrille[x][y] != this.correction[x][y]) return false;
            }
        }
        return true;
    }

    public publishGame(userGrille: number[][],pseudo: string, nbIndice: number): boolean {
        if (!this.isCorrect(userGrille)) return false;
        this.http.post<string>(this.saveGameApiUrl,{"date":new Date(),"playerName":pseudo,"clues":nbIndice}).subscribe();
        return true;
    }

    private transformFormat(grill: number[][]): number[][] {
        // convertie le format de la grille pour faciliter l'affichage après.
        let newgrid: number[][] = [];
        for (let y=0; y<9; y++) {
            newgrid.push([]);
            for (let x=0; x<9; x++) {
                newgrid[y].push(0);
            }
        }
        for (let y=0; y<grill.length; y++) {
            for (let x=0; x<grill[y].length; x++) {
                let a = this.getXYfromOtherXY(x,y);
                newgrid[a[1]][a[0]] =grill[y][x];
            }
        }
        return newgrid;
    }

    private getXYfromOtherXY(x:number, y:number):number[] {
        // transforme les coordonées d'un point du systhème de représentation de l'API au systhème de représentation interne à l'application
        let a = Math.floor(x/3);
        let b = Math.floor(y/3);
        let newy:number = b*3+a;
        let newx:number = (y%3)*3+(x%3);
        return [newx,newy];
    }
}