import { HttpClient, HttpErrorResponse } from '@angular/common/http';
import { Injectable } from "@angular/core";
import { User } from "../models/user.model";

@Injectable()
export class UserService {
    private users: User[];
    private readonly userApiUrl = 'https://664ba07f35bbda10987d9f99.mockapi.io/api/users';
    private pageSize: number = 5;

    public constructor(private http: HttpClient){
        this.users = [];

        this.http.get<User[]>(this.userApiUrl).subscribe(users => {
            users.forEach(user => {
                this.addUserToLocal(user);
            });
        });
    }

    public getAll(): User[]{
        return this.users;
    }

    public getUserById(id: number): User | undefined{
        return this.users.find(user => user.id === id);
        let user: User;
        this.http.get<User>(this.userApiUrl).subscribe(u => {
            user = u;
        });
    }

    public getNbPage(): number {
        return Math.ceil(this.users.length / this.pageSize)
    }

    public getUserNbPts(nbPage:number, sortSens:number): User[] {
        if (nbPage>this.getNbPage() || nbPage<=0) return[];
        let page = this.HardCopy(this.users);
        page = page.sort((a,b) => {
            if (a.points == null || b.points == null) return 0;
            if (a.points>b.points) return 1*sortSens;
            if (b.points>a.points) return -1*sortSens;
            return 0;
        });
        page = this.getSubset(page,(nbPage-1)*this.pageSize,nbPage*this.pageSize);
        return page;
    }

    public getUserNbStreak(nbPage:number, sortSens:number): User[] {
        if (nbPage>this.getNbPage() || nbPage<=0) return[];
        let page = this.HardCopy(this.users);
        page = page.sort((a,b) => {
            if (a.streak == null || b.streak == null) return 0
            if (a.streak>b.streak) return 1*sortSens;
            if (b.streak>a.streak) return -1*sortSens;
            return 0;
        });
        page = this.getSubset(page,(nbPage-1)*this.pageSize,nbPage*this.pageSize);
        return page;
    }

    private addUserToLocal(user: User): void{
        this.users.push(user);
    }

    private HardCopy(users: User[]):User[] {
        return JSON.parse(JSON.stringify(users));
    }

    private getSubset(user: User[],deb:number,fin:number):User[] {
        let a: User[] = [];
        for (let i=0; i<user.length; i++) {
            if (deb<=i && fin>i) {
                a.push(user[i]);
            }
        }
        return a;
    }
}